/*
 * sht4x.h
 *
 *  Created on: Jun 8, 2021
 *      Author: user
 */

#ifndef INC_SHT4X_H_
#define INC_SHT4X_H_

#include "stdint.h"
#include "stm32l0xx_ll_i2c.h"
#include "stm32l0xx_ll_utils.h"
#include "i2c.h"
#include "crc8.h"

/*
 * Defines & macros
 */

#define SCD4X_I2C_ADDRESS 0x62

/*
 * Return values
 */

#define SCD4X_OK 0
#define SCD4X_ERROR -1 // generic error
#define SCD4X_CRC8_ERROR -2 // checksum failed

/*
 * Data types
 */

typedef enum {
	START_PERIODIC_MEASUREMENT = 0x21B1,
	READ_MEASUREMENT = 0xEC05,
	STOP_PERIODIC_MEASUREMENT = 0x3F86,
	GET_DATA_READY_STATUS = 0xe4b8,
	PERFORM_FACTORY_RESET = 0x3632
} scd4x_cmd_t;

/*
 * Function prototypes
 */

int8_t scd4x_send_cmd(scd4x_cmd_t cmd);
int8_t scd4x_read_data(uint8_t *buffer, int len);

int8_t scd4x_start_periodic_measurement( void );
int8_t scd4x_stop_periodic_measurement( void );

int8_t scd4x_perform_factory_reset( void );

int8_t scd4x_read_measurement(int * co2, int *temperature, int *relative_humidity);

#endif /* INC_SHT4X_H_ */
